estimate: estimate

View source: R/core.R

estimateR Documentation

estimate

Description

Apply a neural Bayes estimator to data

Usage

estimate(estimator, Z, batchsize = 32, ...)

Arguments

estimator

a neural estimator that can be applied to data in a call of the form estimator(Z)

Z

data in a format amenable to the neural-network architecture of estimator

batchsize

the batch size for applying estimator to Z

...

additional keyword arguments passed to the Julia version of estimate()

Value

a matrix of outputs resulting from applying estimator to Z

See Also

infer() for a unified inference interface, and sampleposterior() for making inference with neural posterior or likelihood-to-evidence-ratio estimators


NeuralEstimators documentation built on Sept. 10, 2026, 1:12 a.m.