infer: infer

View source: R/core.R

inferR Documentation

infer

Description

Unified inference interface that dispatches to estimate() for neural Bayes estimators (e.g., PointEstimator) and sampleposterior() for posterior or ratio estimators.

Usage

infer(estimator, Z, ...)

Arguments

estimator

a neural estimator

Z

data in a format amenable to the neural-network architecture of estimator

...

additional keyword arguments passed to the Julia version of infer() (and hence to estimate() or sampleposterior())

Value

For neural Bayes estimators, a matrix of point estimates (see estimate()). For posterior or ratio estimators, a d \times N \times K array of posterior samples (see sampleposterior()).

See Also

estimate(), sampleposterior()


NeuralEstimators documentation built on Sept. 10, 2026, 1:12 a.m.