| loadstate | R Documentation |
Load a saved state of a neural estimator (e.g., optimised neural-network parameters). Useful for amortised inference, whereby a neural network is trained once and then used repeatedly to make inference with new data sets.
loadstate(estimator, filename)
estimator |
the neural estimator that we wish to load the state into |
filename |
file name (including path) of the neural-network state stored in a |
estimator updated with the saved state
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.