logratio: logratio

View source: R/core.R

logratioR Documentation

logratio

Description

Apply a neural ratio estimator to data

Usage

logratio(estimator, Z, grid, batchsize = 32, ...)

Arguments

estimator

a neural ratio estimator

Z

data in a format amenable to the neural-network architecture of estimator

grid

matrix of parameter values, where each column is a parameter configuration

batchsize

the batch size

...

additional keyword arguments passed to the Julia version of logratio()

Value

A matrix of log ratios with one row per data set and one column per grid point

See Also

sampleposterior() and infer() for making posterior inferences


NeuralEstimators documentation built on Sept. 10, 2026, 1:12 a.m.