| tanhloss | R Documentation |
For k > 0, defines Julia code that defines the loss function,
L(\hat{\theta}, \theta) = \tanh\left(\frac{|\hat{\theta} - \theta|}{k}\right),
which approximates the 0-1 loss as k tends to zero.
The resulting string is intended to be used in the function train, but can also be converted to a callable function using juliaEval.
tanhloss(k)
k |
Positive numeric value that controls the smoothness of the approximation. |
String defining the tanh loss function in Julia code.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.