| assess | R Documentation |
assess a neural estimator
assess(estimator, parameters, Z, ...)
estimator |
a neural estimator (or a list of neural estimators) |
parameters |
true parameters, stored as a |
Z |
data simulated conditionally on the |
... |
additional keyword arguments passed to the Julia version of |
a list with the following elements:
estimates: a long-form data frame with columns
"parameter"; the name of the parameter
"truth"; the true value of the parameter
"estimate"; the estimated value of the parameter
"k"; the index of the parameter vector in the test set
"j"; the index of the data set
For an IntervalEstimator, estimate is replaced by columns lower and upper. For a QuantileEstimator, there is an additional column prob giving the probability level of each quantile estimate.
runtimes: a data frame giving the total time taken for each estimator
samples (posterior and ratio estimators only): posterior samples stored as a long-form Julia DataFrame with columns parameter, truth, k, and j as above, plus draw (the index of the draw) and value (the sampled value). This object is not converted to an R data frame, which is slow for large sample collections; extract or summarise it in Julia if needed.
risk(), rmse(), bias(), plotestimates(), and plotdistribution() for computing various empirical diagnostics and visualisations from an object returned by assess()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.