| estimate | R Documentation |
Apply a neural Bayes estimator to data
estimate(estimator, Z, batchsize = 32, ...)
estimator |
a neural estimator that can be applied to data in a call of the form |
Z |
data in a format amenable to the neural-network architecture of |
batchsize |
the batch size for applying |
... |
additional keyword arguments passed to the Julia version of |
a matrix of outputs resulting from applying estimator to Z
infer() for a unified inference interface, and sampleposterior() for making inference with neural posterior or likelihood-to-evidence-ratio estimators
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.