| infer | R Documentation |
Unified inference interface that dispatches to estimate() for neural Bayes estimators (e.g., PointEstimator) and sampleposterior() for posterior or ratio estimators.
infer(estimator, Z, ...)
estimator |
a neural estimator |
Z |
data in a format amenable to the neural-network architecture of |
... |
additional keyword arguments passed to the Julia version of |
For neural Bayes estimators, a matrix of point estimates (see estimate()). For posterior or ratio estimators, a d \times N \times K array of posterior samples (see sampleposterior()).
estimate(), sampleposterior()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.