| logratio | R Documentation |
Apply a neural ratio estimator to data
logratio(estimator, Z, grid, batchsize = 32, ...)
estimator |
a neural ratio estimator |
Z |
data in a format amenable to the neural-network architecture of |
grid |
matrix of parameter values, where each column is a parameter configuration |
batchsize |
the batch size |
... |
additional keyword arguments passed to the Julia version of |
A matrix of log ratios with one row per data set and one column per grid point
sampleposterior() and infer() for making posterior inferences
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.