| sampleposterior | R Documentation |
Samples from the approximate posterior distribution given data Z.
sampleposterior(estimator, Z, N = 1000, ...)
estimator |
a neural posterior or likelihood-to-evidence-ratio estimator |
Z |
data in a format amenable to the neural-network architecture of |
N |
number of approximate posterior samples to draw |
... |
additional keyword arguments passed to the Julia version of |
a d \times N \times K array of posterior samples, where d is the dimension of the parameter vector, N is the number of draws, and K is the number of independent data sets in Z (so a single data set yields a d \times N \times 1 array)
infer() for a unified inference interface, and estimate() for making inference with neural Bayes estimators
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.